@@ -1,5 +1,6 @@
+# -*- coding: utf-8 -*-
 __all__ = ('NotFound', 'ModificationError', 'ObjectDeleted', 'DuplicateKeyError', 'MigrationError',
-           'VersionError', 'IntegrityError', 'ReferenceError', 'ConnectionError')
+           'VersionError', 'IntegrityError', 'ReferenceError', 'ConnectionError', 'MergeError')
 
 
 class ConnectionError(Exception):  # pylint: disable=redefined-builtin
@@ -35,8 +36,25 @@ class IntegrityError(Exception):
     constraint"""
 
 
+class MergeError(Exception):
+    """Indicates that an error occurred when trying to merge"""
+
+
 class ReferenceError(IntegrityError):  # pylint: disable=redefined-builtin
+    """Raised when there is an operation that causes a problem with references for example if
+    you try to delete an object that is referenced by another this exception will be raised.  The
+    objects ids being referenced will be found in .references.
+    """
 
     def __init__(self, msg, references: set):
         super().__init__(msg)
         self.references = references
+
+
+class UnorderedError(Exception):
+    """Raised when an operation is attempted that assumed an underlying ordering but the data is
+    unordered"""
+
+
+class NotOneError(Exception):
+    """Raised when a singlar result is expected but there are in fact more"""
