@@ -1,10 +1,11 @@
+# -*- coding: utf-8 -*-
 """Module containing functions to generate query operations.  To prevent clashes with python
 builtins we append underscores to the function names.  This also makes it safer to import this
 module as a wildcard import.
 """
 
 __all__ = ('and_', 'or_', 'eq_', 'exists_', 'elem_match_', 'gt_', 'gte_', 'in_', 'lt_', 'lte_',
-           'ne_', 'nin_', 'Q_')
+           'ne_', 'nin_')
 
 # region Logical operators
 
@@ -93,40 +94,9 @@ def ne_(value) -> dict:
 def nin_(*possibilities) -> dict:
     """Match values that are not equal to any of the possibilities"""
     if len(possibilities) == 1:
-        return possibilities[0]
+        return ne_(possibilities[0])
 
     return {'$nin': list(possibilities)}
 
 
 # endregion
-
-
-class Q_:  # pylint: disable=invalid-name
-    """A query operations helper class"""
-
-    @staticmethod
-    def __eq__(value):
-        return eq_(value)
-
-    @staticmethod
-    def __gt__(quantity):
-        return gt_(quantity)
-
-    @staticmethod
-    def __ge__(quantity):
-        return gt_(quantity)
-
-    @staticmethod
-    def __lt__(quantity):
-        return lt_(quantity)
-
-    @staticmethod
-    def __le__(quantity):
-        return lte_(quantity)
-
-    @staticmethod
-    def __ne__(value):
-        return ne_(value)
-
-    def __init__(self):
-        raise RuntimeError("Cannot instantiate, this is to be used statically")
