@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 import pytest
 
 import mincepy
@@ -13,16 +14,19 @@ def test_load(historian: mincepy.Historian):
     # Check loading from 'cold'
     del car
     car = mincepy.load(car_id)
-    assert car._historian == historian
+    assert car._historian is historian  # pylint: disable=protected-access
 
 
 def test_save(historian: mincepy.Historian):
     car = Car()
     mincepy.save(car)
-    assert car._historian is historian
+    assert car._historian is historian  # pylint: disable=protected-access
 
 
 def test_invalid_connect():
     """Check we get the right error when attempting to connect to invalid archive"""
     with pytest.raises(mincepy.ConnectionError):
-        mincepy.connect('mongodb://unknown-server/db')
+        mincepy.connect('mongodb://unknown-server/db', timeout=5)
+
+    with pytest.raises(ValueError):
+        mincepy.connect('unknown-protocol://nowhere', timeout=5)
